% *************************************************************************
% 
%                      iGem Modelling - 2016
%                     Delft University of Technology
% 
% *************************************************************************
% 
%               Title
% 
%                    File: Growth trate
%                           Model:Determining growth rate from OD values 
% 
%              
% *************************************************************************


function [fit1]=growthrate(time,MeanOD, x0,Ni)
%%
% This fucntion fits the time and MeanOD data with initial guess x0 to the function:
% N(t)=Nm*N0.*(q.*exp(u*t)+1)./(N0*q.*(exp(u*t)-1)+Nm*(q+1))
% Where N(0)=Ni. 
% N is the bacterial cell concentration 
% The growthrate is determined by anaytical solving the differntial
% equation for the Braanyu and Robers model *
% ** Alternative Approach To Modeling Bacterial Lag Time, Using Logistic
% Regression as a Function of Time, Temperature, pH, and Sodium Chloride
% Concentration, Shige Koseki and Junko Nonaka, FEMS Yeast Res 14 (2014) 586600**

%%
global N0
N0              = Ni;                                                           % N(0)=N0
fit1            = lsqcurvefit(@Fit_OD_growth, x0, time,MeanOD);                  % Fit the data
Nfit            = fit1(2)*N0.*(fit1(3).*exp(fit1(1)*time)+1)...
                  ./(N0*fit1(3).*(exp(fit1(1)*time)-1)+fit1(2)*(fit1(3)+1));    % Fitted N(t)
% figure(1)
% hold on 
% plot(time,Nfit)
% plot(time,MeanOD,'+')

end
function Fit = Fit_OD_growth(ig,t)
global N0
u               = ig(1);                                        % Initial guess for u (Maxiumum specific growth rate)
Nm              = ig(2);                                        % Initial guess for Nm (Maximal cell concentration) 
q               = ig(3);                                        % Initial guess q (Initial value for a dimensionless quantity related to the physiological state of the cell) 
Fit = Nm*N0.*(q.*exp(u*t)+1)./(N0*q.*(exp(u*t)-1)+Nm*(q+1));    % Finding the fit for the data
end


